@@ -113,14 +113,14 @@ class BaseApiWrapper:
         )
         return headers_dict
 
-    def get_page(self, page: int = 1, select=None, request_filter=None, order_by=None, annotations=None, query_dict=None):
+    def get_page(self, page_url: str = None, select=None, request_filter=None, order_by=None, annotations=None, query_dict=None):
         """
         Used for getting a first page of list API data,
         or a specific page if such page url has been cached.
 
         :raises D365ApiError: if http request is not "Ok"
         :raises D36pApiWrapperError: if requested page url is not cached or is out of range
-        :param page:
+        :param page_url: autogenerated url for next page, returned with api response
         :param select: string with comma separated attribute names of an entity to include, defaults to all
         :param request_filter: filter string
         :param order_by:
@@ -134,8 +134,8 @@ class BaseApiWrapper:
         if annotations:
             headers = self._update_prefer_header(headers, 'odata.include-annotations', f'"{annotations}"')
         params = {}
-        if page == 1:
-            url = self.api_url
+        if not page_url:
+            page_url = self.api_url
             if select:
                 params['$select'] = select
             if request_filter:
@@ -144,30 +144,13 @@ class BaseApiWrapper:
                 params['$orderby'] = order_by
             if query_dict:
                 params.update(query_dict)
-        else:
-            if self.page_urls.get(page) == '__none__':
-                raise D36pApiWrapperError(f'The page you requested is out of range.')
-            if page not in self.page_urls:
-                pages = sorted(self.page_urls.keys())
-                raise D36pApiWrapperError(f'The url for the page you requested is not cashed. Available pages are '
-                                          f'{pages[0]} trough {pages[-1]}. Try to get the highest available page and'
-                                          f' then use "get_next_page()" method until you get to desired page.')
-            url = self.page_urls.get(page, None)
 
-        response = requests.get(url, params=params, headers=headers)
+        response = requests.get(page_url, params=params, headers=headers)
         if response.ok:
-            self.current_page = page
-            self.page_urls[page + 1] = response.json().get('@odata.nextLink', '__none__')
             return response.json()
         else:
             raise D365ApiError({'response_status_code': response.status_code, 'response_data': response.content})
 
-    def get_next_page(self):
-        if self.current_page:
-            return self.get_page(page=self.current_page + 1)
-        raise D36pApiWrapperError('To call "get_next_page()" "current_page" attribute can not be None. '
-                                  'Please call "get_page()" method first.')
-
     def get_previous_page(self):
         if not self.current_page or self.current_page == 1:
             raise D36pApiWrapperError('To call "get_next_page()" "current_page" attribute can not be None or 1. Please '
